summaryrefslogtreecommitdiff
path: root/tcwg_kernel-build.sh
diff options
context:
space:
mode:
authorMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2018-12-06 19:24:21 +0000
committerMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2018-12-11 15:49:44 +0000
commit850e23e5166fe2f0de481b3e1704317a33bb468a (patch)
treedf5a39701e5cd98cc9fee79e607f5a770b52cd04 /tcwg_kernel-build.sh
parent5d1de6f179f7b69bc6d57a0edfb63b9e2dc11bac (diff)
tcwg_kernel-build.sh: Add --mode continue
Add new "--mode continue" for developer purposes. Preserve existing artifacts and continue build from specified step. Change-Id: I4694cd8ae08f8ea2a5ef9a6c891c731449dc572e
Diffstat (limited to 'tcwg_kernel-build.sh')
-rwxr-xr-xtcwg_kernel-build.sh15
1 files changed, 13 insertions, 2 deletions
diff --git a/tcwg_kernel-build.sh b/tcwg_kernel-build.sh
index 0c8df057..5c232521 100755
--- a/tcwg_kernel-build.sh
+++ b/tcwg_kernel-build.sh
@@ -14,7 +14,7 @@ convert_args_to_variables @@ $scripts/tcwg_kernel/gnu-default.sh \
@@ $scripts/tcwg_kernel/linux-default.sh \
"$@"
# Execution mode: baseline, jenkins-full, bisect.
mode="${mode-baseline}"
# Toolchain to use: gnu or llvm
@@ -89,6 +89,11 @@ case "$mode" in
default_finish_at="check_regression"
git_read_only=true
;;
+ "continue")
+ # Developer mode.
+ default_start_at="prepare_abe"
+ git_read_only=true
+ ;;
"jenkins-full") ;;
esac
@@ -99,7 +104,13 @@ if [ x"$finish_at" = x"default" ]; then
finish_at="$default_finish_at"
fi
-run_step_init "$start_at" "$finish_at" "$top_artifacts" "base-artifacts" "$verbose"
+if [ x"$mode" != x"continue" ]; then
+ base_artifacts_opt="base-artifacts"
+else
+ base_artifacts_opt=""
+fi
+
+run_step_init "$start_at" "$finish_at" "$top_artifacts" "$base_artifacts_opt" "$verbose"
# Reset artifacts to an empty state. $top_artifacts/results is the most
# important artifact, since it records the metric of how successful the build
@@ $scripts/tcwg_kernel/linux-default.sh \
"$@"
-# Execution mode: baseline, jenkins-full, bisect.
+# Execution mode: baseline, jenkins-full, bisect, continue.
mode="${mode-baseline}"
# Toolchain to use: gnu or llvm